@@ -7,34 +7,17 @@ use parent 'RPi::WiringPi::Core';
 use parent 'RPi::WiringPi::Util';
 use parent 'RPi::WiringPi::Meta';
 
-#use GPSD::Parse;
-#use RPi::ADC::ADS;
-#use RPi::ADC::MCP3008;
-#use RPi::BMP180;
 use Carp qw(croak confess);
 use Data::Dumper;
 use RPi::Const qw(:all);
-#use RPi::DAC::MCP4922;
-#use RPi::DigiPot::MCP4XXXX;
-#use RPi::EEPROM::AT24C32;
-#use RPi::GPIOExpander::MCP23017;
-#use RPi::HCSR04;
-#use RPi::I2C;
-#use RPi::LCD;
-#use RPi::OLED::SSD1306::128_64;
-#use RPi::Pin;
-#use RPi::RTC::DS3231;
-#use RPi::Serial;
-#use RPi::SPI;
-#use RPi::StepperMotor;
 
-our $VERSION = '2.3633_02';
+our $VERSION = '2.3633_03';
 
 # class variables
 
 my $fatal_exit = 1;
 my %sig_handlers;
-my $signal_debug = 1;
+my $signal_debug = 0;
 
 # core
 
@@ -84,26 +67,33 @@ sub new {
 
     $self->_fatal_exit($args{fatal_exit});
 
-    $self->meta_lock;
-    my $meta = $self->meta_fetch;
+    $self->{shm_key} //= 'rpiw';
+    $self->meta($self->{shm_key});
 
-    while (! defined $self->{uuid}){
-        my $uuid = $self->checksum;
-        next if exists $meta->{objects}{$uuid};
-        $self->{uuid} = $uuid;
+    if ($self->_rpi_register) {
+        # register all objects for collision detection and safety shutdown
+
+        $self->meta_lock;
+        my $meta = $self->meta_fetch;
+
+        while (!defined $self->{uuid}) {
+            my $uuid = $self->checksum;
+            next if exists $meta->{objects}{$uuid};
+            $self->{uuid} = $uuid;
+        }
+
+        $meta->{objects}{$self->uuid} = {
+            proc  => $self->{proc},
+            label => $self->{label}
+        };
+        $meta->{object_count}++;
+
+        $self->meta_store($meta);
+        $self->meta_unlock;
+
+        $self->_generate_signal_handlers;
     }
 
-    $meta->{objects}{$self->uuid} = {
-        proc  => $self->{proc},
-        label => $self->{label}
-    };
-    $meta->{object_count}++;
-
-    $self->meta_store($meta);
-    $self->meta_unlock;
-
-    $self->_generate_signal_handlers;
-
     return $self;
 }
 sub adc {
@@ -175,7 +165,7 @@ sub hcsr04 {
 }
 sub hygrometer {
     my ($self, $pin) = @_;
-    $self->register_pin($pin, 'DHT11 Hygrometer Signal');
+    $self->pin($pin, "DHT11 Hygrometer Signal");
     require RPi::DHT11;
     RPi::DHT11->import;
     return RPi::DHT11->new($pin);
@@ -237,13 +227,20 @@ sub pin {
 
     my $gpio = $self->pin_to_gpio($pin_num);
 
-    if (grep {$gpio == $_} @{ $self->registered_pins }){
-        croak "\npin $pin_num is already in use... can't create second object\n";
+    if ($self->_rpi_register && $self->_rpi_register_pins) {
+        # both object and pin registration is enabled
+
+        if (grep {$gpio == $_} @{$self->registered_pins}) {
+            croak "\npin $pin_num is already in use... can't create second object\n";
+        }
     }
 
     my $pin = RPi::Pin->new($pin_num, $comment);
 
-    $self->register_pin($pin);
+    if ($self->_rpi_register && $self->_rpi_register_pins) {
+        # register the pin
+        $self->register_pin($pin);
+    }
 
     return $pin;
 }
@@ -382,13 +379,11 @@ sub _cleanup_handler {
             " with fatal_exit = " . $self->_fatal_exit . "\n";
     }
 
-    if ($self->_fatal_exit){
-        delete $sig_handlers{$sig}{$self->uuid};
-    
-        if (scalar(keys %{ $sig_handlers{$sig} }) == 0){
-            $self->cleanup;
-            exit;
-        }
+    delete $sig_handlers{$sig}{$self->uuid};
+    $self->cleanup;
+
+    if ($self->_fatal_exit) {
+        #FIXME: add an object count per proc in meta, and exit if it's 0
     }
 }
 sub _signal_handlers {
@@ -404,6 +399,9 @@ sub _fatal_exit {
 }
 sub _pwm_in_use {
     my $self = shift;
+
+    return if ! $self->_rpi_register_pins || ! $self->_rpi_register;
+
     if ($_[0]){
         $self->meta_lock;
         my $meta = $self->meta_fetch;
@@ -417,15 +415,6 @@ sub _setup {
 }
 
 END {
-#    my $done_cleanup = eval {
-#        if (! %{ $meta_data }){
-#            exit;
-#        };
-#    };
-
-#    if (keys %{ $meta_data->{objects} } == 0){
-#        IPC::Shareable->clean_up_all;
-#    }
 }
 
 sub _vim{};
@@ -508,7 +497,14 @@ Returns a new C<RPi::WiringPi> object. We exclusively use the C<GPIO>
 (Broadcom (BCM) GPIO) pin numbering scheme.
  
 Parameters:
- 
+
+    shm_key => $string
+
+By default, we use the key C<rpiw> as the shared memory segment key. You can
+change this if desired. Useful for separating "groups" of Pi objects from one
+another (for example, production scripts can operate at the same time as test
+scripts, and both use their own shared memory pool).
+
     fatal_exit => $bool
  
 Optional: We trap all C<die()> calls and clean up for safety reasons. If a
@@ -520,7 +516,19 @@ We recommend only disabling this feature if you're doing unit test work, want to
 allow other exit traps to catch, allow the Pi to continue on working after a
 fatal error etc. If disabled, you will be responsible for doing your own cleanup
 of the Pi hardware configuration on exit.
- 
+
+    rpi_register => $bool
+
+Optional: Set this value to false (C<0>) to bypass the Pi object registration in
+the meta data. This will also prevent pins from being registered as well. If set
+to false, no object or pin cleanup will take place at the end of a program run.
+
+    rpi_register_pins => $bool
+
+Optional: Similar to C<rpi_register>, but only bypasses the pin registration.
+Object registration will still occur, and the object will be cleaned up after
+but the pins will not. Should only be used for testing.
+
 =head2 adc
  
 There are two different ADCs that you can select from. The default is the
@@ -695,7 +703,15 @@ Parameters:
  
 Optional, Integer: The I2C address of the RTC module. Defaults to C<0x68> for
 the C<DS3231> unit.
- 
+
+=head2 eeprom
+
+Creates and returns a new L<RPi::EEPROM::AT24C32> object for reading and writing
+to.
+
+See the linked documentation for full documentation on usage, parameters or the
+L<RPi::WiringPi::FAQ> for some usage examples.
+
 =head2 expander
  
 Creates a new L<RPi::GPIOExpander::MCP23017> GPIO expander chip object. This
@@ -986,4 +1002,3 @@ Copyright (C) 2016-2019 by Steve Bertrand
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
 at your option, any later version of Perl 5 you may have available.
-
