@@ -5,7 +5,12 @@ use strict;
 
 use RPi::WiringPi;
 
-my $pi = RPi::WiringPi->new(label => 'serial_arduino_display');
+my $pi = RPi::WiringPi->new(
+    label   => 'serial_arduino_display',
+    rpi_register => 0,
+    shm_key => 'rpit',
+);
+
 my $dev = '/dev/ttyS0';
 my $baud = 9600;
 
