@@ -7,29 +7,63 @@ use Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
+    rpi_sudo_check
+    rpi_multi_check
+    rpi_pod_check
     rpi_running_test
     rpi_check_pin_status
     rpi_oled_available
     rpi_oled_unavailable
     rpi_metadata_clean
     rpi_legal_object_count
+    rpi_legal_pin_count
 );
 
 use RPi::WiringPi;
 use Carp qw(croak);
-use IPC::Shareable;
 use Test::More;
 use WiringPi::API qw(:perl);
 
+# validate that tests can run
+
+if (! $ENV{PI_BOARD} && ! $ENV{SUDO_USER}){
+    $ENV{NO_BOARD} = 1;
+    plan skip_all => "Not on a Pi board";
+}
+if (! defined $ENV{RPI_OBJECT_COUNT} && ! $ENV{SUDO_USER}){
+    plan skip_all => "RPI_OBJECT_COUNT env var not set";
+}
+
+my $legal_object_count = $ENV{RPI_OBJECT_COUNT};
+my $legal_pin_count = $ENV{RPI_PIN_COUNT};
+
 my $oled_lock = '/dev/shm/oled_unavailable.rpi-wiringpi';
 
 sub rpi_legal_object_count {
-    return 3; # crontab-run scripts
+    return $legal_object_count; # crontab-run scripts
+}
+sub rpi_legal_pin_count {
+    return $legal_pin_count; # crontab-run scripts
+}
+sub rpi_sudo_check {
+    if (! $ENV{RPI_SUDO} && $> != 0){
+        plan skip_all => "RPI_SUDO env var not set\n";
+    }
+}
+sub rpi_multi_check {
+    if (!$ENV{RPI_MULTI}) {
+        plan skip_all => "RPI_MULTI environment variable not set\n";
+    }
+}
+sub rpi_pod_check {
+    if (!$ENV{RPI_POD}) {
+        plan skip_all => "RPI_POD environment variable not set\n";
+    }
 }
 sub rpi_running_test {
     (my $test) = @_;
 
-    my $pi = RPi::WiringPi->new(label => 't/RPiTest.pm');
+    my $pi = RPi::WiringPi->new(label => 't/RPiTest.pm', shm_key => 'rpit');
     $pi->meta_lock;
     my $meta = $pi->meta_fetch;
     
@@ -38,7 +72,7 @@ sub rpi_running_test {
         $meta->{testing}{test_name} = $2;
         $pi->meta_store($meta);
         $pi->meta_unlock;
-        $pi->unregister_object;
+        $pi->cleanup;
         return 0;
     }
     elsif ($test =~ /^-\d+/){
@@ -46,7 +80,7 @@ sub rpi_running_test {
         $meta->{testing}{test_name} = '';
         $pi->meta_store($meta);
         $pi->meta_unlock;
-        $pi->unregister_object;
+        $pi->cleanup;
         return 0;
     }
 
@@ -54,9 +88,6 @@ sub rpi_running_test {
         "rpi_running_test() couldn't translate '$test' to a usable shared format\n";
 }
 sub rpi_metadata_clean {
-#    print "$_\n" for keys %{ $meta{objects} };
-#    is scalar(keys(% { $meta{objects} })), 0, "meta is all cleaned up";
-#    IPC::Shareable->clean_up_all;
 }
 sub rpi_oled_available {
     my ($available) = @_;
